define([
    "base1/cockpit",
    "./react",
    "./cockpit-components-terminal",
    "shell/po",
], function(cockpit, React, componentsTerminal, po) {

    "use strict";

    cockpit.locale(po);
    cockpit.translate();

    /*
     * A terminal component for the cockpit user.
     *
     * Uses the Terminal component from base1 internally, but adds a header
     * with title and Reset button.
     *
     * Spawns the user's shell in the user's home directory.
     */
    var UserTerminal = React.createClass({displayName: "UserTerminal",
        createChannel: function (user) {
            return cockpit.channel({
                "payload": "stream",
                "spawn": [ user.shell || "/bin/bash", "-i"],
                "environ": [
                    "TERM=xterm-256color",
                    "PATH=/sbin:/bin:/usr/sbin:/usr/bin"
                ],
                "directory": user.home || "/",
                "pty": true
            });
        },

        getInitialState: function () {
            return {
                title: 'Terminal'
            };
        },

        componentWillMount: function () {
            cockpit.user().done(function (user) {
                this.setState({ user: user, channel: this.createChannel(user) });
            }.bind(this));
        },

        onTitleChanged: function (title) {
            this.setState({ title: title });
        },

        onResetClick: function (event) {
            if (event.button !== 0)
                return;

            if (this.state.channel)
                this.state.channel.close();

            if (this.state.user)
                this.setState({ channel: this.createChannel(this.state.user) });

            // don't focus the button, but keep it on the terminal
            this.refs.resetButton.blur();
            this.refs.terminal.focus();
        },

        render: function () {
            var terminal;
            if (this.state.channel)
                terminal = (React.createElement(componentsTerminal.Terminal, {ref: "terminal", 
                                                         channel: this.state.channel, 
                                                         onTitleChanged: this.onTitleChanged}));
            else
                terminal = React.createElement("span", null, "Loading...");

            return (
                React.createElement("div", {className: "panel panel-default console-ct-container"}, 
                    React.createElement("div", {className: "panel-heading"}, 
                        React.createElement("tt", {className: "terminal-title"}, this.state.title), 
                        React.createElement("button", {ref: "resetButton", 
                                className: "btn btn-default pull-right", 
                                onClick: this.onResetClick}, "Reset")
                    ), 
                    terminal
                )
            );
        }
    });

    React.render(React.createElement(UserTerminal, null), document.getElementById('terminal'));

    /* And show the body */
    document.body.removeAttribute("hidden");
});
